@@ -7,6 +7,7 @@
  * Description : a kipi plugin to slide images.
  *
  * Copyright (C) 2008-2009 by Valerio Fuoglio <valerio dot fuoglio at gmail dot com>
+ * Copyright (C) 2009      by Andi Clemens <andi dot clemens at gmx dot net>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -36,8 +37,8 @@
 
 // Phonon includes
 
-#include <Phonon/Global>
-#include <Phonon/MediaObject>
+#include <phonon/globalconfig.h>
+#include <phonon/mediaobject.h>
 
 // KDE includes
 
@@ -63,7 +64,7 @@ public:
 
 Q_SIGNALS:
 
-    void totalTimeReady(KUrl, QTime);
+    void signalTotalTimeReady(const KUrl&, const QTime&);
 
 private Q_SLOTS:
 
@@ -88,9 +89,13 @@ public:
 
     ListSoundItems(QWidget *parent = 0);
 
+public:
+
+    KUrl::List fileUrls();
+
 Q_SIGNALS:
 
-    void addedDropItems(KUrl::List filesUrl);
+    void signalAddedDropItems(const KUrl::List& filesUrl);
 
 protected:
 
