@@ -24,14 +24,14 @@
 #ifndef SLIDESHOWCONFIG_H
 #define SLIDESHOWCONFIG_H
 
-// Local includes
+// KDE includes.
 
-#include "common.h"
+#include <kpagedialog.h>
 
 namespace KIPIAdvancedSlideshowPlugin
 {
 
-class SharedData;
+class SharedContainer;
 
 class SlideShowConfigPrivate;
 
@@ -41,7 +41,7 @@ class SlideShowConfig : public KPageDialog
 
 public:
 
-    SlideShowConfig (QWidget *parent, SharedData* sharedData);
+    SlideShowConfig (QWidget *parent, SharedContainer* sharedData);
     ~SlideShowConfig();
 
 Q_SIGNALS:
