@@ -1,22 +1,23 @@
 /* ============================================================
- * File  : slideshowgl.cpp
- * Author: Renchi Raju <renchi@pooh.tam.uiuc.edu>
- * Date  : 2004-01-19
- * Description :
  *
- * Copyright (C) 2004      by Renchi Raju <renchi@pooh.tam.uiuc.edu>
+ * This file is a part of kipi-plugins project
+ * http://www.kipi-plugins.org
+ *
+ * Date        : 2004-01-19
+ * Description : a kipi plugin to slide images.
+ *
+ * Copyright (C) 2004      by Renchi Raju <renchi dot raju at gmail dot com>
  * Copyright (C) 2006-2009 by Valerio Fuoglio <valerio.fuoglio@gmail.com>
  * Copyright (C) 2009      by Andi Clemens <andi dot clemens at gmx dot net>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
  * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
+ * either version 2, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU General Public License for more details.
  *
  * ============================================================ */
@@ -58,11 +59,22 @@
 #include <klocale.h>
 #include <kstandarddirs.h>
 
+// libkipi includes
+
+#include <libkipi/imageinfo.h>
+
+// local includes.
+
+#include "commoncontainer.h"
+#include "playbackwidget.h"
+#include "slideplaybackwidget.h"
+#include "slideshowloader.h"
+
 namespace KIPIAdvancedSlideshowPlugin
 {
 
 SlideShowGL::SlideShowGL(const QList<QPair<QString, int> >& fileList,
-                         const QStringList& commentsList, SharedData* sharedData)
+                         const QStringList& commentsList, SharedContainer* sharedData)
            : QGLWidget(0, 0, Qt::WindowStaysOnTopHint | Qt::Popup | Qt::X11BypassWindowManagerHint)
 {
     setAttribute(Qt::WA_DeleteOnClose);
@@ -589,8 +601,8 @@ void SlideShowGL::printProgress(QImage& layer)
 void SlideShowGL::printComments(QImage& layer)
 {
 //    QString comments = m_commentsList[m_fileIndex];
-    KIPI::ImageInfo info = m_sharedData->interface->info(m_imageLoader->currPath());
-    QString comments = info.description();
+    KIPI::ImageInfo info = m_sharedData->iface()->info(m_imageLoader->currPath());
+    QString comments     = info.description();
 
     int yPos = 5; // Text Y coordinate
 
@@ -684,7 +696,7 @@ void SlideShowGL::showEndOfShow()
     p.drawText(20, 50, i18n("Slideshow Completed"));
     p.drawText(20, 100, i18n("Click to Exit..."));
 
-    QSvgRenderer svgRenderer( KStandardDirs::locate("data", "kipiplugin_advancedslideshow/KIPIicon.svg") );
+    QSvgRenderer svgRenderer( KStandardDirs::locate("data", "kipi/data/kipi-icon.svg") );
     QPixmap kipiLogoPixmap = QPixmap(width()/6, width()/6);
     kipiLogoPixmap.fill(Qt::black);
     QPaintDevice* pdp = &kipiLogoPixmap;
@@ -742,7 +754,7 @@ void SlideShowGL::slotTimeOut()
 {
     if (!m_effect)
     {
-        kWarning( 51000 ) << "SlideShowGL: No transition method";
+        kWarning() << "SlideShowGL: No transition method";
         m_effect = &SlideShowGL::effectNone;
     }
 
