@@ -40,10 +40,6 @@
 #include <libkdcraw/version.h>
 #include <libkdcraw/kdcraw.h>
 
-#if KDCRAW_VERSION < 0x000400
-#include <libkdcraw/dcrawbinary.h>
-#endif
-
 // Libkipi includes
 
 #include <libkipi/interface.h>
@@ -76,11 +72,7 @@ void LoadThread::run()
     QImage newImage;
 
     // check if it's a RAW file.
-#if KDCRAW_VERSION < 0x000400
-    QString rawFilesExt(KDcrawIface::DcrawBinary::instance()->rawFiles());
-#else
     QString rawFilesExt(KDcrawIface::KDcraw::rawFiles());
-#endif
     QFileInfo fileInfo(m_path.toLocalFile());
     if (rawFilesExt.toUpper().contains(fileInfo.suffix().toUpper()))
     {
