@@ -43,9 +43,9 @@
 
 // Phonon includes
 
-#include <Phonon/AudioOutput>
-#include <Phonon/BackendCapabilities>
-#include <Phonon/MediaObject>
+#include <phonon/audiooutput.h>
+#include <phonon/backendcapabilities.h>
+#include <phonon/mediaobject.h>
 
 // Local includes
 
