@@ -24,15 +24,6 @@
 #include "renameimageswidget.h"
 #include "renameimageswidget.moc"
 
-// C ANSI includes
-
-extern "C"
-{
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <unistd.h>
-}
-
 // C++ includes
 
 #include <cstdio>
@@ -42,7 +33,6 @@ extern "C"
 
 #include <QMenu>
 #include <QAction>
-#include <QProgressDialog>
 #include <QGroupBox>
 #include <QCheckBox>
 #include <QDir>
@@ -62,10 +52,10 @@ extern "C"
 
 #include <kconfig.h>
 #include <kdebug.h>
-#include <kdeversion.h>
-#include <kio/previewjob.h>
 #include <kio/renamedialog.h>
 #include <klocale.h>
+#include <kde_file.h>
+#include <kprogressdialog.h>
 
 // LibKIPI includes
 
@@ -162,15 +152,10 @@ RenameImagesWidget::RenameImagesWidget(QWidget *parent, KIPI::Interface* interfa
             this, SLOT(moveCurrentItemDown()));
 
     m_timer    = new QTimer(this);
-    m_progress = new QProgressDialog(this);
-    m_progress->setModal(true);
 
     connect(m_timer, SIGNAL(timeout()),
             this, SLOT(slotNext()));
 
-    connect(m_progress, SIGNAL(canceled()),
-            this, SLOT(slotAbort()));
-
     connect(m_interface, SIGNAL(gotThumbnail(const KUrl&, const QPixmap&)),
             this, SLOT(slotGotPreview(const KUrl&, const QPixmap&)));
 
@@ -191,7 +176,6 @@ RenameImagesWidget::RenameImagesWidget(QWidget *parent, KIPI::Interface* interfa
 RenameImagesWidget::~RenameImagesWidget()
 {
     delete m_timer;
-    delete m_progress;
 
     saveSettings();
 
@@ -373,7 +357,7 @@ QString RenameImagesWidget::oldToNewName(BatchProcessImagesItem* item, int itemP
     if (ui->m_addFileNameCheck->isChecked())
     {
         newName += fi.baseName();
-        newName += "_";
+        newName += '_';
     }
 
     int seqNumber = itemPosition + ui->m_seqSpin->value();
@@ -403,7 +387,7 @@ QString RenameImagesWidget::oldToNewName(BatchProcessImagesItem* item, int itemP
                     {
                         QString fmt;
                         fmt.sprintf("0%dd", (k > 10 ? 10 : k));
-                        fmt = "%" + fmt;
+                        fmt = '%' + fmt;
                         to.sprintf(fmt.toLatin1(), seqNumber);
                     }
                 }
@@ -441,8 +425,8 @@ QString RenameImagesWidget::oldToNewName(BatchProcessImagesItem* item, int itemP
             }
         }
         format.replace("%%", "%");
-        format.replace("%s", "");
-        format.replace("/", "!");
+        format.remove("%s");
+        format.replace('/', '!');
         format.replace("%[", "% [");
 
         time_t time        = info.time().toTime_t();
@@ -453,7 +437,7 @@ QString RenameImagesWidget::oldToNewName(BatchProcessImagesItem* item, int itemP
         newName += QString::fromLocal8Bit(s);
         if (!useExtraSymbols)
         {
-            newName += "_";
+            newName += '_';
         }
     }
 
@@ -469,7 +453,7 @@ QString RenameImagesWidget::oldToNewName(BatchProcessImagesItem* item, int itemP
 
         QString format;
         format.sprintf("0%dd", numDigits);
-        format = "%" + format;
+        format = '%' + format;
 
         QString seq;
         seq.sprintf(format.toLatin1(), seqNumber);
@@ -495,9 +479,16 @@ void RenameImagesWidget::slotStart()
     ui->m_listView->setCurrentItem(item);
     ui->m_listView->scrollToItem(item);
 
-    m_progress->setMaximum(ui->m_listView->topLevelItemCount());
-    m_progress->setValue(0);
-    m_progress->show();
+
+    m_progress = new KProgressDialog(this);
+    m_progress->setAutoReset(true);
+    m_progress->setAutoClose(true);
+    m_progress->progressBar()->setMaximum(ui->m_listView->topLevelItemCount());
+    m_progress->progressBar()->setValue(0);
+
+    connect(m_progress, SIGNAL(cancelClicked()),
+            this, SLOT(slotAbort()));
+
 
     m_overwriteAll = false;
     m_autoSkip     = false;
@@ -506,7 +497,7 @@ void RenameImagesWidget::slotStart()
 void RenameImagesWidget::slotAbort()
 {
     m_timer->stop();
-    m_progress->reset();
+    m_progress->progressBar()->reset();
     m_progress->hide();
 }
 
@@ -530,8 +521,8 @@ void RenameImagesWidget::slotNext()
 
     if (!m_overwriteAll)
     {
-        struct stat info;
-        while (::stat(QFile::encodeName(dst.path()), &info) == 0)
+        KDE_struct_stat info;
+        while (KDE_stat(QFile::encodeName(dst.path()), &info) == 0)
         {
             if (m_autoSkip)
             {
@@ -587,27 +578,27 @@ void RenameImagesWidget::slotNext()
 
     if (skip)
     {
-        item->changeResult(i18n("Skipped"));
+        item->changeResult(i18nc("batch process result", "Skipped"));
     }
     else
     {
         // Get the src info
         KIPI::ImageInfo srcInfo = m_interface->info(src);
 
-        if (::rename(QFile::encodeName(src.path()),
+        if (KDE_rename(QFile::encodeName(src.path()),
                      QFile::encodeName(dst.path())) == 0)
         {
             srcInfo.setTitle(dst.fileName());
 
-            item->changeResult(i18n("OK"));
+            item->changeResult(i18nc("batch process result", "OK"));
         }
         else
         {
-            item->changeResult(i18n("Failed"));
+            item->changeResult(i18nc("batch process result", "Failed"));
         }
     }
 
-    m_progress->setValue(m_progress->value() + 1);
+    m_progress->progressBar()->setValue(m_progress->progressBar()->value() + 1);
 
     it = ui->m_listView->itemBelow(it);
     if (it)
