@@ -6,7 +6,8 @@
  * Date        : 2008-11-07
  * Description : DNG converter about data.
  *
- * Copyright (C) 2008-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010 by Jens Mueller <tschenser at gmx dot de>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -47,11 +48,16 @@ public:
         : KPAboutData(ki18n("DNG Image Converter"), 0,
                       KAboutData::License_GPL,
                       ki18n("A tool to batch convert RAW camera images to DNG"),
-                      ki18n("(c) 2008-2009, Gilles Caulier"))
+                      ki18n("(c) 2008-2009, Gilles Caulier\n"
+                            "(c) 2010, Jens Mueller"))
     {
          addAuthor(ki18n("Gilles Caulier"),
                    ki18n("Author"),
                    "caulier dot gilles at gmail dot com");
+
+         addAuthor(ki18n("Jens Mueller"),
+                   ki18n("Developer"),
+                   "tschenser at gmx dot de");
     }
 
     ~DNGConverterAboutData(){}
