@@ -7,6 +7,7 @@
  * Description : a tool to export image to an Ipod device.
  *
  * Copyright (C) 2006-2008 by Seb Ruiz <ruiz@kde.org>
+ * Copyright (C) 2008-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -23,11 +24,6 @@
 #ifndef IPOD_EXPORTDIALOG_H
 #define IPOD_EXPORTDIALOG_H
 
-extern "C"
-{
-#include <gpod/itdb.h>
-}
-
 #define KIPI_PLUGIN 1
 
 // Qt includes
@@ -46,12 +42,20 @@ extern "C"
 #include "kpaboutdata.h"
 #include "pluginsversion.h"
 #include "imagedialog.h"
-#endif
+#endif // KIPI_PLUGIN
+
+// Libgpod includes.
+
+extern "C"
+{
+#include <gpod/itdb.h>
+}
 
 class QGroupBox;
 class QLabel;
 class QPushButton;
 class QTreeWidgetItem;
+class QCloseEvent;
 
 class KFileItem;
 
@@ -68,7 +72,7 @@ class IpodHeader;
 
 class UploadDialog : public KDialog
 {
-Q_OBJECT
+    Q_OBJECT
 
 public:
 
@@ -86,14 +90,21 @@ public:
     QString mountPoint() { return m_mountPoint; }
     QString deviceNode() { return m_deviceNode; }
 
+    /**
+     * Use this method to (re-)activate the dialog after it has been created
+     * to display it. This also loads the currently selected images.
+     */
+    void reactivate();
+    void loadImagesFromCurrentSelection();
+
 private Q_SLOTS:
 
     void startTransfer();
 
-    void addDropItems( QStringList filesPath );
+    void addDropItems( const QStringList& filesPath );
 
     void imageSelected( QTreeWidgetItem *item );
-    void gotImagePreview( const KFileItem* , const QPixmap &pixmap );
+    void gotImagePreview( const KFileItem*, const QPixmap &pixmap );
 
     void ipodItemSelected( QTreeWidgetItem *item );
 
@@ -107,13 +118,14 @@ private Q_SLOTS:
     void refreshDevices();
     void updateSysInfo();
 
-    void slotHelp();
-
     void enableButtons();
 
+    void slotHelp();
+    void slotClose();
+
 private:
 
-    void addUrlToList( QString file );
+    void addUrlToList( const QString& file );
     bool deleteIpodAlbum( IpodAlbumItem *album );
     bool deleteIpodPhoto( IpodPhotoItem *photo );
     void getIpodAlbums();
@@ -122,36 +134,40 @@ private:
     void reloadIpodAlbum( IpodAlbumItem *item, Itdb_PhotoAlbum *album );
 
     bool openDevice(); // connect to the ipod
+    void closeEvent(QCloseEvent*);
+
+private:
+
+    bool                 m_transferring;
 
 #if KIPI_PLUGIN
-    Interface       *m_interface;
-    KPAboutData     *m_about;
+    Interface           *m_interface;
+    KPAboutData         *m_about;
 #endif
 
-    Itdb_PhotoDB    *m_itdb;
-    Itdb_IpodInfo   *m_ipodInfo;
-    IpodHeader      *m_ipodHeader;
-    bool             m_transferring;
+    Itdb_PhotoDB        *m_itdb;
+    Itdb_IpodInfo       *m_ipodInfo;
+    IpodHeader          *m_ipodHeader;
 
-    QGroupBox       *m_destinationBox;
-    QGroupBox       *m_urlListBox;
+    QGroupBox           *m_destinationBox;
+    QGroupBox           *m_urlListBox;
 
-    QPushButton     *m_createAlbumButton;
-    QPushButton     *m_removeAlbumButton;
-    QPushButton     *m_renameAlbumButton;
-    QPushButton     *m_addImagesButton;
-    QPushButton     *m_remImagesButton;
-    QPushButton     *m_transferImagesButton;
+    QPushButton         *m_createAlbumButton;
+    QPushButton         *m_removeAlbumButton;
+    QPushButton         *m_renameAlbumButton;
+    QPushButton         *m_addImagesButton;
+    QPushButton         *m_remImagesButton;
+    QPushButton         *m_transferImagesButton;
 
-    QLabel          *m_imagePreview;
-    QLabel          *m_ipodPreview;
+    QLabel              *m_imagePreview;
+    QLabel              *m_ipodPreview;
 
-    QString          m_mountPoint;
-    QString          m_deviceNode;
+    QString              m_mountPoint;
+    QString              m_deviceNode;
 
-    ImageList       *m_ipodAlbumList;
+    ImageList           *m_ipodAlbumList;
 
-    ImageList       *m_uploadList;
+    ImageList           *m_uploadList;
 
     static UploadDialog *s_instance;
 };
