@@ -7,7 +7,7 @@
  * Description : a kipi plugin to export images to Picasa web service
  *
  * Copyright (C) 2007-2008 by Vardhman Jain <vardhman at gmail dot com>
- * Copyright (C) 2008-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2009 by Luka Renko <lure at kubuntu dot org>
  *
  * This program is free software; you can redistribute it
@@ -22,7 +22,6 @@
  *
  * ============================================================ */
 
-#include "picasawebtalker.h"
 #include "picasawebtalker.moc"
 
 // C++ includes
@@ -133,7 +132,8 @@ void PicasawebTalker::getToken(const QString& username, const QString& password
     QString accountType = "GOOGLE";
 
     QStringList qsl;
-    qsl.append("Email="+QUrl::toPercentEncoding(username_edit));
+    // do not encode username to support email adress
+    qsl.append("Email="+username_edit);
     qsl.append("Passwd="+QUrl::toPercentEncoding(password_edit));
     qsl.append("accountType="+accountType);
     qsl.append("service=lh2");
@@ -146,7 +146,6 @@ void PicasawebTalker::getToken(const QString& username, const QString& password
     job->addMetaData("content-type", "Content-Type: application/x-www-form-urlencoded" );
     m_state = FE_GETTOKEN;
     emit signalLoginProgress(1, 2, "Getting the token");
-    //authProgressDlg->setLabelText(i18n("Getting the token"));
 
     connect(job, SIGNAL(data(KIO::Job*, const QByteArray&)),
             this, SLOT(data(KIO::Job*, const QByteArray&)));
@@ -185,7 +184,7 @@ void PicasawebTalker::checkToken(const QString& token)
     }
 
     KUrl url("http://picasaweb.google.com/data/feed/api");
-    url.addPath("/user/" + QUrl::toPercentEncoding(m_username));
+    url.addPath("/user/" + m_username);
     kDebug() << " token value is " << token ;
     QString auth_string = "GoogleLogin auth=" + token;
     KIO::TransferJob* job = KIO::get(url, KIO::NoReload, KIO::HideProgressInfo);
@@ -221,7 +220,8 @@ void PicasawebTalker::listAlbums(const QString& username)
         m_job = 0;
     }
     KUrl url("http://picasaweb.google.com/data/feed/api");
-    url.addPath("/user/" + QUrl::toPercentEncoding(username));
+    // do not encode username to support email adress
+    url.addPath("/user/" + username);
     KIO::TransferJob* job = KIO::get(url, KIO::NoReload, KIO::HideProgressInfo);
     job->ui()->setWindow(m_parent);
     job->addMetaData("content-type", "Content-Type: application/x-www-form-urlencoded" );
@@ -252,7 +252,7 @@ void PicasawebTalker::listPhotos(const QString& username,
         m_job = 0;
     }
     KUrl url("http://picasaweb.google.com/data/feed/api");
-    url.addPath("/user/" + QUrl::toPercentEncoding(username));
+    url.addPath("/user/" + username);
     url.addPath("/albumid/" + albumId);
     url.addQueryItem("thumbsize", "200");
     KIO::TransferJob* job = KIO::get(url, KIO::NoReload, KIO::HideProgressInfo);
@@ -331,7 +331,7 @@ void PicasawebTalker::createAlbum(const PicasaWebAlbum& album)
     buffer.append(docMeta.toString().toUtf8());
 
     KUrl url("http://picasaweb.google.com/data/feed/api");
-    url.addPath("/user/" + QUrl::toPercentEncoding(m_username));
+    url.addPath("/user/" + m_username);
     QString auth_string = "GoogleLogin auth=" + m_token;
     KIO::TransferJob* job = KIO::http_post(url, buffer, KIO::HideProgressInfo);
     job->ui()->setWindow(m_parent);
@@ -361,7 +361,7 @@ bool PicasawebTalker::addPhoto(const QString& photoPath, PicasaWebPhoto& info,
     }
 
     KUrl url("http://picasaweb.google.com/data/feed/api");
-    url.addPath("/user/" + QUrl::toPercentEncoding(m_username));
+    url.addPath("/user/" + m_username);
     url.addPath("/albumid/" + albumId);
     QString     auth_string = "GoogleLogin auth=" + m_token;
     MPForm      form;
@@ -733,6 +733,11 @@ void PicasawebTalker::parseResponseListAlbums(const QByteArray& data)
 
     while(!node.isNull())
     {
+        if(node.isElement() && node.nodeName() == "gphoto:user")
+        {
+            m_username = node.toElement().text();
+        }
+
         if (node.isElement() && node.nodeName() == "entry")
         {
             e = node.toElement();
