@@ -7,7 +7,7 @@
  * Description : a kipi plugin to export images to Picasa web service
  *
  * Copyright (C) 2007-2008 by Vardhman Jain <vardhman at gmail dot com>
- * Copyright (C) 2008-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2009 by Luka Renko <lure at kubuntu dot org>
  * Copyright (C) 2010 by Jens Mueller <tschenser at gmx dot de>
  *
@@ -23,7 +23,6 @@
  *
  * ============================================================ */
 
-#include "picasawebwindow.h"
 #include "picasawebwindow.moc"
 
 // Qt includes
@@ -33,6 +32,7 @@
 #include <QCheckBox>
 #include <QGroupBox>
 #include <QCloseEvent>
+#include <QButtonGroup>
 
 // KDE includes
 
@@ -63,13 +63,11 @@
 
 // LibKIPI includes
 
-#include <libkipi/interface.h>
 #include <libkipi/uploadwidget.h>
 
 // Local includes
 
 #include "imageslist.h"
-#include "kpaboutdata.h"
 #include "newalbumdialog.h"
 #include "picasawebalbum.h"
 #include "picasawebitem.h"
@@ -83,7 +81,7 @@ namespace KIPIPicasawebExportPlugin
 
 PicasawebWindow::PicasawebWindow(KIPI::Interface* interface, const QString& tmpFolder,
                                  bool import, QWidget* /*parent*/)
-          : KDialog(0)
+               : KDialog(0)
 {
     m_tmpPath.clear();
     m_tmpDir      = tmpFolder;
@@ -116,7 +114,6 @@ PicasawebWindow::PicasawebWindow(KIPI::Interface* interface, const QString& tmpF
         m_widget->setMinimumSize(700, 500);
     }
 
-
     connect(m_widget, SIGNAL( signalUserChangeRequest(bool) ),
             this, SLOT( slotUserChangeRequest(bool)) );
 
@@ -134,15 +131,15 @@ PicasawebWindow::PicasawebWindow(KIPI::Interface* interface, const QString& tmpF
 
     // ------------------------------------------------------------------------
 
-    m_about = new KIPIPlugins::KPAboutData(ki18n("PicasaWeb Export"),
-                                           0,
-                                           KAboutData::License_GPL,
-                                           ki18n("A Kipi plugin to export image collections to "
-                                                 "PicasaWeb web service."),
-                                           ki18n( "(c) 2007-2009, Vardhman Jain\n"
-                                           "(c) 2008-2009, Gilles Caulier\n"
-                                           "(c) 2009, Luka Renko\n"
-                                           "(c) 2010, Jens Mueller" ));
+    m_about = new KPAboutData(ki18n("PicasaWeb Export"),
+                              0,
+                              KAboutData::License_GPL,
+                              ki18n("A Kipi plugin to export image collections to "
+                                    "PicasaWeb web service."),
+                              ki18n( "(c) 2007-2009, Vardhman Jain\n"
+                              "(c) 2008-2010, Gilles Caulier\n"
+                              "(c) 2009, Luka Renko\n"
+                              "(c) 2010, Jens Mueller" ));
 
     m_about->addAuthor(ki18n( "Vardhman Jain" ), ki18n("Author and maintainer"),
                        "Vardhman at gmail dot com");
@@ -283,6 +280,7 @@ void PicasawebWindow::readSettings()
 
     m_widget->m_dimensionSpB->setValue(grp.readEntry("Maximum Width", 1600));
     m_widget->m_imageQualitySpB->setValue(grp.readEntry("Image Quality", 85));
+    m_widget->m_tagsBGrp->button(grp.readEntry("Tag Paths", 0))->setChecked(true);
 }
 
 void PicasawebWindow::writeSettings()
@@ -296,6 +294,7 @@ void PicasawebWindow::writeSettings()
     grp.writeEntry("Resize",        m_widget->m_resizeChB->isChecked());
     grp.writeEntry("Maximum Width", m_widget->m_dimensionSpB->value());
     grp.writeEntry("Image Quality", m_widget->m_imageQualitySpB->value());
+    grp.writeEntry("Tag Paths",     m_widget->m_tagsBGrp->checkedId());
 }
 
 void PicasawebWindow::slotLoginProgress(int step, int maxStep, const QString &label)
@@ -318,11 +317,9 @@ void PicasawebWindow::slotLoginDone(int errCode, const QString& errMsg)
     if (errCode == 0 /*TODO&& m_talker->loggedIn()*/)
     {
         buttonStateChange(true);
-        m_username = m_talker->getUserName();
         m_token = m_talker->token();
-        m_widget->updateLabels(m_username);
         m_widget->m_albumsCoB->clear();
-        m_talker->listAlbums(m_username);
+        m_talker->listAlbums(m_talker->getUserName());
     }
     else
     {
@@ -339,6 +336,9 @@ void PicasawebWindow::slotListAlbumsDone(int errCode, const QString &errMsg,
         return;
     }
 
+    m_username = m_talker->getUserName();
+    m_widget->updateLabels(m_username);
+
     m_widget->m_albumsCoB->clear();
     for (int i = 0; i < albumsList.size(); ++i)
     {
@@ -442,49 +442,12 @@ void PicasawebWindow::slotListPhotosDoneForUpload(int errCode, const QString &er
             }
         }
 
-        QStringList allTags;
-        QStringList::Iterator itTags;
-        /*TODO
-        QStringList tagsFromDialog = m_tagsLineEdit->text().split(' ', QString::SkipEmptyParts);
-
-        // Tags from the interface
-        itTags = tagsFromDialog.begin();
-
-        while( itTags != tagsFromDialog.end() )
-        {
-            allTags.append( *itTags );
-            ++itTags;
-        }
-        */
-
         //Tags from the database
         QMap <QString, QVariant> attribs = info.attributes();
         temp.gpsLat = attribs["latitude"].toString();
         temp.gpsLon = attribs["longitude"].toString();
 
-        QStringList tagsFromDatabase;
-
-        //TODOif(m_exportApplicationTags->isChecked())
-        {
-            tagsFromDatabase=attribs["tags"].toStringList();
-        }
-
-        itTags = tagsFromDatabase.begin();
-
-        while( itTags != tagsFromDatabase.end() )
-        {
-            allTags.append( *itTags );
-            ++itTags;
-        }
-
-        itTags = allTags.begin();
-
-        while( itTags != allTags.end() )
-        {
-            ++itTags;
-        }
-
-        temp.tags=allTags;
+        temp.tags = attribs["tagspath"].toStringList();
         m_transferQueue.append( Pair( (*it), temp) );
     }
 
@@ -707,9 +670,58 @@ void PicasawebWindow::uploadNextPhoto()
         }
     }
 
+    //modify tags
+    switch (m_widget->m_tagsBGrp->checkedId())
+    {
+    case PwTagLeaf:
+        {
+            QStringList newTags;
+            QStringList::const_iterator itT;
+            for(itT = info.tags.constBegin(); itT != info.tags.constEnd(); itT++)
+            {
+                QString strTmp = *itT;
+                int idx = strTmp.lastIndexOf("/");
+                if (idx > 0)
+                {
+                    strTmp.remove(0, idx + 1);
+                }
+                newTags.append(strTmp);
+            }
+            info.tags = newTags;
+        }
+        break;
+    case PwTagSplit:
+        {
+            QSet<QString> newTagsSet;
+            QStringList::const_iterator itT;
+            for(itT = info.tags.constBegin(); itT != info.tags.constEnd(); itT++)
+            {
+                QStringList strListTmp = itT->split("/");
+                QStringList::const_iterator itT2;
+                for(itT2 = strListTmp.constBegin(); itT2 != strListTmp.constEnd(); itT2++)
+                {
+                    if (!newTagsSet.contains(*itT2))
+                    {
+                        newTagsSet.insert(*itT2);
+                    }
+                }
+            }
+            info.tags.clear();
+            QSet<QString>::const_iterator itT3;
+            for(itT3 = newTagsSet.begin(); itT3 != newTagsSet.end(); itT3++)
+            {
+                info.tags.append(*itT3);
+            }
+        }
+        break;
+    case PwTagCombined:
+    default:
+        break;
+    }
+
     if (bCancel)
     {
-        cancelProcessing();;
+        cancelProcessing();
         res = true;
     }
     else
