@@ -1132,11 +1132,13 @@ void Wizard::previewPhotos()
   // send this photo list to the painter
   QImage img ( d->mPhotoPage->BmpFirstPagePreview->size(), QImage::Format_ARGB32_Premultiplied );
   QPainter p ( &img );
-  p.setCompositionMode( QPainter::CompositionMode_Destination );
-  p.fillRect ( img.rect(), Qt::transparent );
+  p.setCompositionMode(QPainter::CompositionMode_Clear);
+  //p.setCompositionMode(QPainter::CompositionMode_Destination );
+  p.fillRect (img.rect(), Qt::color0);//Qt::transparent );
   p.setCompositionMode( QPainter::CompositionMode_SourceOver );
   paintOnePage ( p, d->m_photos, s->layouts, current, d->mCropPage->m_disableCrop->isChecked(), true );
   p.end();
+  d->mPhotoPage->BmpFirstPagePreview->clear();
   d->mPhotoPage->BmpFirstPagePreview->setPixmap ( QPixmap::fromImage(img) );
   d->mPhotoPage->LblPreview->setText ( i18n ( "Page %1 of %2", d->m_currentPreviewPage + 1, getPageCount() ) );
 
@@ -1483,7 +1485,7 @@ void Wizard::outputChanged ( const QString & text)
     {
       if (it->printerName () == text)
       {
-          kDebug() << "Choosen printer: " << it->printerName ();
+          kDebug() << "Chosen printer: " << it->printerName ();
           if (d->m_printer)
             delete d->m_printer;
           d->m_printer = new QPrinter(*it);
