@@ -21,7 +21,6 @@
  *
  * ============================================================ */
 
-#include "batchdialog.h"
 #include "batchdialog.moc"
 
 // C ANSI includes
@@ -88,6 +87,7 @@ extern "C"
 #include "savesettingswidget.h"
 
 using namespace KDcrawIface;
+using namespace KIPIPlugins;
 
 namespace KIPIRawConverterPlugin
 {
@@ -112,30 +112,30 @@ public:
         iface               = 0;
     }
 
-    bool                      busy;
-    bool                      convertBlink;
+    bool                 busy;
+    bool                 convertBlink;
 
-    QTimer                   *blinkConvertTimer;
+    QTimer*              blinkConvertTimer;
 
-    QWidget                  *page;
+    QWidget*             page;
 
-    QStringList               fileList;
+    QStringList          fileList;
 
-    QProgressBar             *progressBar;
+    QProgressBar*        progressBar;
 
-    QTreeWidget              *listView;
+    QTreeWidget*         listView;
 
-    CListViewItem            *currentConvertItem;
+    CListViewItem*       currentConvertItem;
 
-    ActionThread             *thread;
+    ActionThread*        thread;
 
-    SaveSettingsWidget       *saveSettingsBox;
+    SaveSettingsWidget*  saveSettingsBox;
 
-    DcrawSettingsWidget      *decodingSettingsBox;
+    DcrawSettingsWidget* decodingSettingsBox;
 
-    KIPIPlugins::KPAboutData *about;
+    KPAboutData*         about;
 
-    KIPI::Interface          *iface;
+    KIPI::Interface*     iface;
 };
 
 BatchDialog::BatchDialog(KIPI::Interface* iface)
@@ -144,15 +144,15 @@ BatchDialog::BatchDialog(KIPI::Interface* iface)
     d->iface = iface;
 
     setButtons(Help | Default | Apply | Close | User1 | User2);
-    setDefaultButton(KDialog::Close);
+    setDefaultButton(Close);
     setButtonToolTip(Close, i18n("Exit RAW Converter"));
     setCaption(i18n("RAW Image Batch Converter"));
     setModal(false);
-    setButtonIcon(User1, KIcon("list-add"));
-    setButtonText(User1, i18n("&Add"));
+    setButtonIcon(User1,    KIcon("list-add"));
+    setButtonText(User1,    i18n("&Add"));
     setButtonToolTip(User1, i18n("Add new RAW files to the list"));
-    setButtonIcon(User2, KIcon("list-remove"));
-    setButtonText(User2, i18n("&Remove"));
+    setButtonIcon(User2,    KIcon("list-remove"));
+    setButtonText(User2,    i18n("&Remove"));
     setButtonToolTip(User2, i18n("Remove selected RAW files from the list"));
 
     d->page = new QWidget( this );
@@ -222,7 +222,7 @@ BatchDialog::BatchDialog(KIPI::Interface* iface)
                    KAboutData::License_GPL,
                    ki18n("A Kipi plugin to batch convert RAW images"),
                    ki18n("(c) 2003-2005, Renchi Raju\n"
-                         "(c) 2006-2009, Gilles Caulier"));
+                         "(c) 2006-2010, Gilles Caulier"));
 
     d->about->addAuthor(ki18n("Renchi Raju"),
                        ki18n("Author"),
@@ -332,8 +332,8 @@ void BatchDialog::slotClose()
 
 void BatchDialog::slotDefault()
 {
-    d->decodingSettingsBox->setDefaultSettings();
-    d->saveSettingsBox->setDefaultSettings();
+    d->decodingSettingsBox->resetToDefault();
+    d->saveSettingsBox->resetToDefault();
 }
 
 void BatchDialog::readSettings()
@@ -341,52 +341,11 @@ void BatchDialog::readSettings()
     KConfig config("kipirc");
     KConfigGroup group = config.group(QString("RawConverter Settings"));
 
-    d->decodingSettingsBox->setSixteenBits(group.readEntry("Sixteen Bits", false));
-    d->decodingSettingsBox->setWhiteBalance((KDcrawIface::RawDecodingSettings::WhiteBalance)
-                                            group.readEntry("White Balance",
-                                            (int)KDcrawIface::RawDecodingSettings::CAMERA));
-    d->decodingSettingsBox->setCustomWhiteBalance(group.readEntry("Custom White Balance", 6500));
-    d->decodingSettingsBox->setCustomWhiteBalanceGreen(group.readEntry("Custom White Balance Green", 1.0));
-    d->decodingSettingsBox->setFourColor(group.readEntry("Four Color RGB", false));
-    d->decodingSettingsBox->setUnclipColor(group.readEntry("Unclip Color", 0));
-    d->decodingSettingsBox->setDontStretchPixels(group.readEntry("Dont Stretch Pixels", false));
-    d->decodingSettingsBox->setNoiseReduction(group.readEntry("Use Noise Reduction", false));
-    d->decodingSettingsBox->setBrightness(group.readEntry("Brightness Multiplier", 1.0));
-    d->decodingSettingsBox->setUseBlackPoint(group.readEntry("Use Black Point", false));
-    d->decodingSettingsBox->setBlackPoint(group.readEntry("Black Point", 0));
-    d->decodingSettingsBox->setUseWhitePoint(group.readEntry("Use White Point", false));
-    d->decodingSettingsBox->setWhitePoint(group.readEntry("White Point", 0));
-    d->decodingSettingsBox->setMedianFilterPasses(group.readEntry("Median Filter Passes", 0));
-    d->decodingSettingsBox->setNRThreshold(group.readEntry("NR Threshold", 100));
-    d->decodingSettingsBox->setUseCACorrection(group.readEntry("EnableCACorrection", false));
-    d->decodingSettingsBox->setcaRedMultiplier(group.readEntry("caRedMultiplier", 1.0));
-    d->decodingSettingsBox->setcaBlueMultiplier(group.readEntry("caBlueMultiplier", 1.0));
-#if KDCRAW_VERSION >= 0x000500
-    d->decodingSettingsBox->setAutoBrightness(group.readEntry("AutoBrightness", true));
-#endif
-
-    d->decodingSettingsBox->setQuality(
-        (KDcrawIface::RawDecodingSettings::DecodingQuality)group.readEntry("Decoding Quality",
-            (int)(KDcrawIface::RawDecodingSettings::BILINEAR)));
-
-    d->decodingSettingsBox->setOutputColorSpace(
-        (KDcrawIface::RawDecodingSettings::OutputColorSpace)group.readEntry("Output Color Space",
-            (int)(KDcrawIface::RawDecodingSettings::SRGB)));
-
-    d->saveSettingsBox->setFileFormat(
-        (SaveSettingsWidget::OutputFormat)group.readEntry("Output Format",
-            (int)(SaveSettingsWidget::OUTPUT_PNG)));
-
-    d->saveSettingsBox->setConflictRule(
-        (SaveSettingsWidget::ConflictRule)group.readEntry("Conflict",
-            (int)(SaveSettingsWidget::OVERWRITE)));
-
-    d->saveSettingsBox->slotPopulateImageFormat(d->decodingSettingsBox->sixteenBits());
+    d->decodingSettingsBox->readSettings(group);
+    d->saveSettingsBox->readSettings(group);
+    d->saveSettingsBox->slotPopulateImageFormat(d->decodingSettingsBox->settings().sixteenBitsImage);
 
     KConfigGroup group2 = config.group(QString("Batch Raw Converter Dialog"));
-#if KDCRAW_VERSION > 0x000500
-    d->decodingSettingsBox->readSettings();
-#endif
     restoreDialogSize(group2);
 }
 
@@ -395,31 +354,8 @@ void BatchDialog::saveSettings()
     KConfig config("kipirc");
     KConfigGroup group = config.group(QString("RawConverter Settings"));
 
-    group.writeEntry("Sixteen Bits", d->decodingSettingsBox->sixteenBits());
-    group.writeEntry("White Balance", (int)d->decodingSettingsBox->whiteBalance());
-    group.writeEntry("Custom White Balance", d->decodingSettingsBox->customWhiteBalance());
-    group.writeEntry("Custom White Balance Green", d->decodingSettingsBox->customWhiteBalanceGreen());
-    group.writeEntry("Four Color RGB", d->decodingSettingsBox->useFourColor());
-    group.writeEntry("Unclip Color", d->decodingSettingsBox->unclipColor());
-    group.writeEntry("Dont Stretch Pixels", d->decodingSettingsBox->useDontStretchPixels());
-    group.writeEntry("Use Noise Reduction", d->decodingSettingsBox->useNoiseReduction());
-    group.writeEntry("Brightness Multiplier", d->decodingSettingsBox->brightness());
-    group.writeEntry("Use Black Point", d->decodingSettingsBox->useBlackPoint());
-    group.writeEntry("Black Point", d->decodingSettingsBox->blackPoint());
-    group.writeEntry("Use White Point", d->decodingSettingsBox->useWhitePoint());
-    group.writeEntry("White Point", d->decodingSettingsBox->whitePoint());
-    group.writeEntry("Median Filter Passes", d->decodingSettingsBox->medianFilterPasses());
-    group.writeEntry("NR Threshold", d->decodingSettingsBox->NRThreshold());
-    group.writeEntry("EnableCACorrection", d->decodingSettingsBox->useCACorrection());
-    group.writeEntry("caRedMultiplier", d->decodingSettingsBox->caRedMultiplier());
-    group.writeEntry("caBlueMultiplier", d->decodingSettingsBox->caBlueMultiplier());
-    group.writeEntry("Decoding Quality", (int)d->decodingSettingsBox->quality());
-    group.writeEntry("Output Color Space", (int)d->decodingSettingsBox->outputColorSpace());
-#if KDCRAW_VERSION >= 0x000500
-    group.writeEntry("AutoBrightness", d->decodingSettingsBox->useAutoBrightness());
-#endif
-    group.writeEntry("Output Format", (int)d->saveSettingsBox->fileFormat());
-    group.writeEntry("Conflict", (int)d->saveSettingsBox->conflictRule());
+    d->decodingSettingsBox->writeSettings(group);
+    d->saveSettingsBox->writeSettings(group);
 
     KConfigGroup group2 = config.group(QString("Batch Raw Converter Dialog"));
     saveDialogSize(group2);
@@ -459,32 +395,7 @@ void BatchDialog::slotStartStop()
         d->progressBar->setValue(0);
         d->progressBar->show();
 
-        KDcrawIface::RawDecodingSettings rawDecodingSettings;
-        rawDecodingSettings.sixteenBitsImage           = d->decodingSettingsBox->sixteenBits();
-        rawDecodingSettings.whiteBalance               = d->decodingSettingsBox->whiteBalance();
-        rawDecodingSettings.customWhiteBalance         = d->decodingSettingsBox->customWhiteBalance();
-        rawDecodingSettings.customWhiteBalanceGreen    = d->decodingSettingsBox->customWhiteBalanceGreen();
-        rawDecodingSettings.RGBInterpolate4Colors      = d->decodingSettingsBox->useFourColor();
-        rawDecodingSettings.unclipColors               = d->decodingSettingsBox->unclipColor();
-        rawDecodingSettings.DontStretchPixels          = d->decodingSettingsBox->useDontStretchPixels();
-        rawDecodingSettings.enableNoiseReduction       = d->decodingSettingsBox->useNoiseReduction();
-        rawDecodingSettings.brightness                 = d->decodingSettingsBox->brightness();
-        rawDecodingSettings.enableBlackPoint           = d->decodingSettingsBox->useBlackPoint();
-        rawDecodingSettings.blackPoint                 = d->decodingSettingsBox->blackPoint();
-        rawDecodingSettings.enableWhitePoint           = d->decodingSettingsBox->useWhitePoint();
-        rawDecodingSettings.whitePoint                 = d->decodingSettingsBox->whitePoint();
-        rawDecodingSettings.medianFilterPasses         = d->decodingSettingsBox->medianFilterPasses();
-        rawDecodingSettings.NRThreshold                = d->decodingSettingsBox->NRThreshold();
-        rawDecodingSettings.enableCACorrection         = d->decodingSettingsBox->useCACorrection();
-        rawDecodingSettings.caMultiplier[0]            = d->decodingSettingsBox->caRedMultiplier();
-        rawDecodingSettings.caMultiplier[1]            = d->decodingSettingsBox->caBlueMultiplier();
-        rawDecodingSettings.RAWQuality                 = d->decodingSettingsBox->quality();
-        rawDecodingSettings.outputColorSpace           = d->decodingSettingsBox->outputColorSpace();
-#if KDCRAW_VERSION >= 0x000500
-        rawDecodingSettings.autoBrightness             = d->decodingSettingsBox->useAutoBrightness();
-#endif
-
-        d->thread->setRawDecodingSettings(rawDecodingSettings, d->saveSettingsBox->fileFormat());
+        d->thread->setRawDecodingSettings(d->decodingSettingsBox->settings(), d->saveSettingsBox->fileFormat());
         processOne();
     }
     else
