@@ -23,11 +23,11 @@
 #ifndef PLUGIN_SENDIMAGES_H
 #define PLUGIN_SENDIMAGES_H
 
-// Qt includes.
+// Qt includes
 
 #include <QVariant>
 
-// LibKIPI includes.
+// LibKIPI includes
 
 #include <libkipi/plugin.h>
 
@@ -45,15 +45,19 @@ Q_OBJECT
 
 public:
 
-   Plugin_SendImages(QObject *parent, const QVariantList &args);
-   ~Plugin_SendImages();
+    Plugin_SendImages(QObject *parent, const QVariantList& args);
+    ~Plugin_SendImages();
 
-   virtual KIPI::Category category( KAction* action ) const;
-   virtual void setup( QWidget* );
+    virtual KIPI::Category category( KAction* action ) const;
+    virtual void setup( QWidget* );
 
-public slots:
+public Q_SLOTS:
 
-   void slotActivate();
+    void slotActivate();
+
+private Q_SLOTS:
+
+    void slotPrepareEmail();
 
 private:
 
